==> app_state-0.6.10.tar.gz: lib/src/blocs/page_stack/router_delegate.dart <==
import 'package:flutter/widgets.dart';

import '../../widgets/navigator.dart';
import '../page/path_changed_event.dart';
import 'bloc.dart';
import 'configuration.dart';
import 'event.dart';
import 'page_event.dart';

class PageStackRouterDelegate extends RouterDelegate<PageStackConfiguration>
    with
        ChangeNotifier,
        PopNavigatorRouterDelegateMixin<PageStackConfiguration> {
  final List<NavigatorObserver> observers;
  final PageStackBloc pageStackBloc;
  final TransitionDelegate<dynamic> transitionDelegate;

  PageStackRouterDelegate(
    this.pageStackBloc, {
    this.observers = const <NavigatorObserver>[],
    this.transitionDelegate = const DefaultTransitionDelegate<dynamic>(),
  }) {
    pageStackBloc.events.listen(_onPageStackEvent);
  }

  @override
  final navigatorKey = GlobalKey<NavigatorState>();

  @override
  PageStackConfiguration? get currentConfiguration {
    return pageStackBloc.getConfiguration();
  }

  @override
  Widget build(BuildContext context) {
    return PageStackNavigator(
      bloc: pageStackBloc,
      observers: observers,
      transitionDelegate: transitionDelegate,
    );
  }

  @override
  Future<void> setNewRoutePath(PageStackConfiguration configuration) async {
    return pageStackBloc.setConfiguration(configuration);
  }

  void _onPageStackEvent(PageStackBlocEvent event) {
    if (event is PageStackPageBlocEvent) {
      if (event.pageBlocEvent is PageBlocPathChangedEvent) {
        notifyListeners();
      }
    }
  }
}

==> app_state-0.7.4.tar.gz: lib/src/blocs/page_stack/router_delegate.dart <==
import 'package:flutter/widgets.dart';

import '../../widgets/navigator.dart';
import '../page/path_changed_event.dart';
import 'configuration.dart';
import 'event.dart';
import 'page_event.dart';
import 'page_stack.dart';

class PageStackRouterDelegate extends RouterDelegate<PageStackConfiguration>
    with
        ChangeNotifier,
        PopNavigatorRouterDelegateMixin<PageStackConfiguration> {
  final List<NavigatorObserver> observers;
  final PageStack pageStack;
  final TransitionDelegate<dynamic> transitionDelegate;

  @Deprecated('Renamed to pageStack in v0.7.0')
  PageStack get pageStackBloc => pageStack;

  PageStackRouterDelegate(
    this.pageStack, {
    this.observers = const <NavigatorObserver>[],
    this.transitionDelegate = const DefaultTransitionDelegate<dynamic>(),
  }) {
    pageStack.events.listen(_onPageStackEvent);
  }

  @override
  final navigatorKey = GlobalKey<NavigatorState>();

  @override
  PageStackConfiguration? get currentConfiguration {
    return pageStack.getConfiguration();
  }

  @override
  Widget build(BuildContext context) {
    return PageStackNavigator(
      stack: pageStack,
      observers: observers,
      transitionDelegate: transitionDelegate,
    );
  }

  @override
  Future<void> setNewRoutePath(PageStackConfiguration configuration) async {
    return pageStack.setConfiguration(configuration);
  }

  void _onPageStackEvent(PageStackEvent event) {
    if (event is PageStackPageEvent) {
      if (event.pageEvent is PagePathChangedEvent) {
        notifyListeners();
      }
    }
  }
}
